pub struct WgpuContext {
pub device: Device,
pub queue: Queue,
pub surface: Option<Surface<'static>>,
pub surface_config: Option<SurfaceConfiguration>,
}Expand description
Shared wgpu rendering context
Fields
device: Devicequeue: Queuesurface: Option<Surface<'static>>surface_config: Option<SurfaceConfiguration>Implementations
Sourceimpl WgpuContext
impl WgpuContext
Sourcepub async fn new_offscreen() -> Self
pub async fn new_offscreen() -> Self
Create a new wgpu context without a surface (for library use)
Sourcepub async fn new_with_surface(
window: impl Into<SurfaceTarget<'static>>,
width: u32,
height: u32,
) -> Self
pub async fn new_with_surface( window: impl Into<SurfaceTarget<'static>>, width: u32, height: u32, ) -> Self
Create a new wgpu context with a surface for rendering to a window